@@ -1,10 +1,9 @@
 import requests
-from datetime import date
 
-class TogglClientApi:
+
+class TogglClientApi(object):
 
     defaultCredentials = {
-        'token': '',
         'username': '',
         'workspace_name': '',
         'base_url': 'https://www.toggl.com/api',
@@ -21,10 +20,12 @@ class TogglClientApi:
     requests = None
 
     def __init__(self, credentials):
-        self.credentials = dict(self.defaultCredentials.items() + credentials.items())
+        credentials.update(self.defaultCredentials)
+        self.credentials = credentials
         self.api_base_url = self.build_api_url(self.credentials['base_url'], self.credentials['ver_api'])
         self.api_report_base_url = self.build_api_url(self.credentials['base_url_report'], self.credentials['ver_report'])
         self.api_token = self.credentials['token']
+        self.timeout = self.credentials.get('timeout', 60)
         self.api_username = self.credentials['username']
         self.user_agent = self.credentials['user_agent']
         self.workspace_id = int(self.credentials['workspace_id'])
@@ -36,7 +37,7 @@ class TogglClientApi:
 
     def get_workspace_by_name(self, name):
         workspace_found = None
-        list_response = self.get_workspaces();
+        list_response = self.get_workspaces()
 
         if list_response.status_code != requests.codes.ok:
             list_response.raise_for_status()
@@ -86,8 +87,9 @@ class TogglClientApi:
     """
     @param start_date datetime.date()
     @param end_date datetime.date()
-    """""
-    def get_project_times(self, project_id, start_date, end_date):
+    """
+
+    def get_project_times(self, project_id, start_date, end_date, extra_params={}):
         params = {
             'workspace_id': self.workspace_id,
             'project_ids': project_id,
@@ -97,6 +99,7 @@ class TogglClientApi:
             'grouping': 'users',
             'subgrouping': 'projects'
         }
+        params.update(extra_params)
         time_entries_response = self.query_report('/details', params)
 
         json_response = time_entries_response.json()
@@ -117,16 +120,22 @@ class TogglClientApi:
         if method == "POST":
             return False
         elif method == "GET":
-            response = self._do_get_query(api_endpoint, headers=toggl_headers, auth=toggl_auth, params=params)
+            response = self._do_get_query(
+                api_endpoint, headers=toggl_headers,
+                auth=toggl_auth, params=params,
+                timeout=self.timeout)
         else:
-            response = self._do_get_query(api_endpoint, headers=toggl_headers, auth=toggl_auth, params=params)
+            response = self._do_get_query(
+                api_endpoint, headers=toggl_headers,
+                auth=toggl_auth, params=params,
+                timeout=self.timeout)
 
         return response
 
     @staticmethod
-    def _do_get_query(url, headers, auth, params):
-        print url
-        print params
-        response = requests.get(url, headers=headers, auth=auth, params=params)
+    def _do_get_query(url, headers, auth, params, timeout):
+        response = requests.get(
+            url, headers=headers, auth=auth, params=params,
+            timeout=timeout)
 
-        return response
\ No newline at end of file
+        return response
